==> qt-creator-1.1.0-src.zip: qt-creator-1.1.0-src/src/libs/utils/projectnamevalidatinglineedit.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact:  Qt Software Information (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
**************************************************************************/

#ifndef PROJECTNAMEVALIDATINGLINEEDIT_H
#define PROJECTNAMEVALIDATINGLINEEDIT_H

#include "basevalidatinglineedit.h"

namespace Core {
namespace Utils {

class QWORKBENCH_UTILS_EXPORT ProjectNameValidatingLineEdit : public BaseValidatingLineEdit
{
    Q_OBJECT
    Q_DISABLE_COPY(ProjectNameValidatingLineEdit)

public:
    explicit ProjectNameValidatingLineEdit(QWidget *parent = 0);

    static bool validateProjectName(const QString &name, QString *errorMessage /* = 0*/);

protected:
    virtual bool validate(const QString &value, QString *errorMessage) const;
};

} // namespace Utils
} // namespace Core

#endif // PROJECTNAMEVALIDATINGLINEEDIT_H

==> qt-creator-1.2.0-src.zip: qt-creator-1.2.0-src/src/libs/utils/projectnamevalidatinglineedit.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://www.qtsoftware.com/contact.
**
**************************************************************************/

#ifndef PROJECTNAMEVALIDATINGLINEEDIT_H
#define PROJECTNAMEVALIDATINGLINEEDIT_H

#include "basevalidatinglineedit.h"

namespace Core {
namespace Utils {

class QTCREATOR_UTILS_EXPORT ProjectNameValidatingLineEdit : public BaseValidatingLineEdit
{
    Q_OBJECT
    Q_DISABLE_COPY(ProjectNameValidatingLineEdit)

public:
    explicit ProjectNameValidatingLineEdit(QWidget *parent = 0);

    static bool validateProjectName(const QString &name, QString *errorMessage /* = 0*/);

protected:
    virtual bool validate(const QString &value, QString *errorMessage) const;
};

} // namespace Utils
} // namespace Core

#endif // PROJECTNAMEVALIDATINGLINEEDIT_H
